==> paraview-v0.6.0.zip: paraview-v0.6.0/ParaView/ParaView/vtkPVSourceWidget.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkPVSourceWidget.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "vtkPVSourceWidget.h"

#include "vtkPVApplication.h"

vtkCxxRevisionMacro(vtkPVSourceWidget, "1.5");

//----------------------------------------------------------------------------
vtkPVSourceWidget::vtkPVSourceWidget()
{
  this->SourceTclName = 0;
  this->OutputTclName = 0;
}

//----------------------------------------------------------------------------
vtkPVSourceWidget::~vtkPVSourceWidget()
{

  if (this->OutputTclName)
    {
    vtkPVApplication* pvApp = 
      vtkPVApplication::SafeDownCast(this->Application);
    if (pvApp)
      {
      pvApp->BroadcastScript("%s Delete", this->OutputTclName);
      }
    }

  if (this->SourceTclName)
    {
    vtkPVApplication* pvApp = 
      vtkPVApplication::SafeDownCast(this->Application);
    if (pvApp)
      {
      pvApp->BroadcastScript("%s Delete", this->SourceTclName);
      }
    }

  this->SetSourceTclName(0);
  this->SetOutputTclName(0);
}

//----------------------------------------------------------------------------
void vtkPVSourceWidget::SaveInTclScript(ofstream *file)
{
  char *result;
  
  if (this->ObjectTclName == NULL || this->VariableName == NULL 
      || this->SourceTclName)
    {
    vtkErrorMacro(<< this->GetClassName() << " must not have SaveInTclScript method.");
    return;
    } 

  this->Script("%s GetClassName", this->SourceTclName);
  result = this->Application->GetMainInterp()->result;
  *file << result << " " << this->SourceTclName << "\n";

  *file << "\t" << this->ObjectTclName << " Set" << this->VariableName
        << " " << this->SourceTclName << endl;
}

//----------------------------------------------------------------------------
void vtkPVSourceWidget::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
  os << "Source Tcl name: " << (this->SourceTclName?this->SourceTclName:"none")
     << endl;
  os << "Output Tcl Name: " << (this->OutputTclName?this->OutputTclName:"none")
     << endl;
}

==> paraview-v1.0.4.zip: paraview-v1.0.4/ParaView/ParaView/vtkPVSourceWidget.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkPVSourceWidget.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "vtkPVSourceWidget.h"

#include "vtkPVApplication.h"

vtkCxxRevisionMacro(vtkPVSourceWidget, "1.6");

//----------------------------------------------------------------------------
vtkPVSourceWidget::vtkPVSourceWidget()
{
  this->SourceTclName = 0;
  this->OutputTclName = 0;
}

//----------------------------------------------------------------------------
vtkPVSourceWidget::~vtkPVSourceWidget()
{

  if (this->OutputTclName)
    {
    vtkPVApplication* pvApp = 
      vtkPVApplication::SafeDownCast(this->Application);
    if (pvApp)
      {
      pvApp->BroadcastScript("%s Delete", this->OutputTclName);
      }
    }

  if (this->SourceTclName)
    {
    vtkPVApplication* pvApp = 
      vtkPVApplication::SafeDownCast(this->Application);
    if (pvApp)
      {
      pvApp->BroadcastScript("%s Delete", this->SourceTclName);
      }
    }

  this->SetSourceTclName(0);
  this->SetOutputTclName(0);
}

//----------------------------------------------------------------------------
void vtkPVSourceWidget::SaveInBatchScript(ofstream *file)
{
  char *result;
  
  if (this->SourceTclName)
    {
    return;
    } 

  this->Script("%s GetClassName", this->SourceTclName);
  result = this->Application->GetMainInterp()->result;
  *file << result << " " << this->SourceTclName << "\n";

  // This will loop through all parts and call SaveInBatchScriptForPart.
  this->Superclass::SaveInBatchScript(file);
}

//----------------------------------------------------------------------------
void vtkPVSourceWidget::SaveInBatchScriptForPart(ofstream *file, 
                                                 const char* sourceTclName)
{
  if (sourceTclName == NULL || this->VariableName == NULL)
    {
    return;
    } 

  *file << "\t" << sourceTclName << " Set" << this->VariableName
        << " " << this->SourceTclName << endl;
}

//----------------------------------------------------------------------------
void vtkPVSourceWidget::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
  os << "Source Tcl name: " << (this->SourceTclName?this->SourceTclName:"none")
     << endl;
  os << "Output Tcl Name: " << (this->OutputTclName?this->OutputTclName:"none")
     << endl;
}
